From d02d75ba02e42db03a27c4b987ed3087ec048012 Mon Sep 17 00:00:00 2001
From: Florian Fainelli <florian@openwrt.org>
Date: Sat, 27 Jun 2009 18:58:00 +0000
Subject: [PATCH] fix the flash address comment and register the flash device
 again with its proper physical address on 6338/6345

SVN-Revision: 16587
---
 .../files/arch/mips/bcm63xx/boards/board_bcm963xx.c    | 10 +++++++---
 1 file changed, 7 insertions(+), 3 deletions(-)

diff --git a/target/linux/brcm63xx/files/arch/mips/bcm63xx/boards/board_bcm963xx.c b/target/linux/brcm63xx/files/arch/mips/bcm63xx/boards/board_bcm963xx.c
index 98c9005940..c41951b988 100644
--- a/target/linux/brcm63xx/files/arch/mips/bcm63xx/boards/board_bcm963xx.c
+++ b/target/linux/brcm63xx/files/arch/mips/bcm63xx/boards/board_bcm963xx.c
@@ -324,7 +324,7 @@ void __init board_prom_init(void)
 	u32 val;
 
 	/* read base address of boot chip select (0) 
 	 * 6338 does not have MPI but boots from standard
 	 * MIPS Flash address */
 	if (BCMCPU_IS_6338() || BCMCPU_IS_6345())
 		val = 0x1fc00000;
@@ -554,8 +554,12 @@ int __init board_register_devices(void)
 #endif
 
 	/* read base address of boot chip select (0) */
-	val = bcm_mpi_readl(MPI_CSBASE_REG(0));
-	val &= MPI_CSBASE_BASE_MASK;
+	if (BCMCPU_IS_6338() || BCMCPU_IS_6345())
+		val = 0x1fc0000;
+	else {
+		val = bcm_mpi_readl(MPI_CSBASE_REG(0));
+		val &= MPI_CSBASE_BASE_MASK;
+	}
 	mtd_resources[0].start = val;
 	mtd_resources[0].end = 0x1FFFFFFF;
 
@@ -324,7 +324,7 @@ void __init board_prom_init(void)
 
 	/* read base address of boot chip select (0) 
-	 * 6338 does not have MPI but boots from standard
+	 * 6338/6345 does not have MPI but boots from standard
 	 * MIPS Flash address */
 	if (BCMCPU_IS_6338() || BCMCPU_IS_6345())
-- 
GitLab